"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../logger/logger");
class LoggerClient {
    constructor(client) {
        this.client = client;
    }
    closeConnection() {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('Closing connection...');
            yield this.client.closeConnection();
            logger_1.default.info('Connection closed');
        });
    }
    flushdb() {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('Flushing db...');
            yield this.client.flushdb();
            logger_1.default.info('Db flushed');
        });
    }
    hgetall(key) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('HGETALL ' + key);
            const response = yield this.client.hgetall(key);
            logger_1.default.info(response);
            return response;
        });
    }
    smembers(key) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('SMEMBERS ' + key);
            const response = yield this.client.smembers(key);
            logger_1.default.info(response);
            return response;
        });
    }
    hdel(key, field) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('HDEL ' + key + ' ' + field);
            yield this.client.hdel(key, field);
        });
    }
    srem(key, member) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('SREM ' + key + ' ' + member);
            yield this.client.srem(key, member);
        });
    }
    zrem(key, member) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('ZREM ' + key + ' ' + member);
            yield this.client.zrem(key, member);
        });
    }
    set(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('SET ' + key + ' ' + value);
            yield this.client.set(key, value);
        });
    }
    zadd(key, score, member) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('ZADD ' + key + ' ' + score + ' ' + member);
            yield this.client.zadd(key, score, member);
        });
    }
    sadd(key, member) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('SADD ' + key + ' ' + member);
            yield this.client.sadd(key, member);
        });
    }
    hmset(key, values) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('HMSET ' + key + ' ' + JSON.stringify(values));
            yield this.client.hmset(key, values);
        });
    }
    rpush(key, element) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('RPUSH ' + key + ' ' + element);
            yield this.client.rpush(key, element);
        });
    }
    llen(key) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('LLEN ' + key);
            const response = yield this.client.llen(key);
            logger_1.default.info('LLEN RESPONSE = ' + response);
            return response;
        });
    }
    sscan(key, cursor, pattern) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('SSCAN', key, cursor, 'MATCH', pattern);
            const response = yield this.client.sscan(key, cursor, pattern);
            logger_1.default.info(response);
            return response;
        });
    }
    sinter(keys) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('SINTER ' + JSON.stringify(keys));
            const response = yield this.client.sinter(keys);
            logger_1.default.info(response);
            return response;
        });
    }
    sunion(keys) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('SUNION ' + JSON.stringify(keys));
            const response = yield this.client.sunion(keys);
            logger_1.default.info(response);
            return response;
        });
    }
    zrangebyscore(key, min, max, offset, count) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('ZRANGEBYSCORE', key, min, max, 'LIMIT', offset, count);
            const response = yield this.client.zrangebyscore(key, min, max, offset, count);
            logger_1.default.info(response);
            return response;
        });
    }
    zrange(key, start, stop) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('ZRANGE ' + key + ' ' + start + ' ' + stop);
            const response = yield this.client.zrange(key, start, stop);
            logger_1.default.info(response);
            return response;
        });
    }
    zrevrange(key, start, stop) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('ZREVRANGE ' + key + ' ' + start + ' ' + stop);
            const response = yield this.client.zrevrange(key, start, stop);
            logger_1.default.info(response);
            return response;
        });
    }
    lrange(key, start, stop) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('LRANGE ' + key + ' ' + start + ' ' + stop);
            const response = yield this.client.lrange(key, start, stop);
            logger_1.default.info(response);
            return response;
        });
    }
    lrem(key, count, element) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('LREM ' + key + ' ' + count + ' ' + element);
            yield this.client.lrem(key, count, element);
        });
    }
    del(key) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('DEL ' + key);
            yield this.client.del(key);
        });
    }
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('GET ' + key);
            return yield this.client.get(key);
        });
    }
    hmget(key, properties) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('HMGET ' + key + ' ' + JSON.stringify(properties));
            const response = yield this.client.hmget(key, properties);
            logger_1.default.info(response);
            return response;
        });
    }
    eval(...args) {
        return __awaiter(this, void 0, void 0, function* () {
            logger_1.default.info('EVAL');
            const response = yield this.client.eval(...args);
            logger_1.default.info(response);
            return response;
        });
    }
}
exports.LoggerClient = LoggerClient;
